@@ -1,7 +1,7 @@
 /*  This file is part of the Kate project.
  *
  *  Copyright (C) 2010 Christoph Cullmann <cullmann@kde.org>
- *  Copyright (C) 2010 Dominik Haumann <dhaumann kde org>
+ *  Copyright (C) 2010-2018 Dominik Haumann <dhaumann@kde.org>
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Library General Public
@@ -19,6 +19,7 @@
  *  Boston, MA 02110-1301, USA.
  */
 
+#include <kateglobal.h>
 #include "katetextbuffertest.h"
 #include "katetextbuffer.h"
 #include "katetextcursor.h"
@@ -29,6 +30,7 @@ QTEST_MAIN(KateTextBufferTest)
 KateTextBufferTest::KateTextBufferTest()
     : QObject()
 {
+    KTextEditor::EditorPrivate::enableUnitTestMode();
 }
 
 KateTextBufferTest::~KateTextBufferTest()
@@ -38,13 +40,13 @@ KateTextBufferTest::~KateTextBufferTest()
 void KateTextBufferTest::basicBufferTest()
 {
     // construct an empty text buffer
-    Kate::TextBuffer buffer(0, 1);
+    Kate::TextBuffer buffer(nullptr, 1);
 
     // one line per default
     QVERIFY(buffer.lines() == 1);
     QVERIFY(buffer.text() == QString());
 
-    //FIXME: use QTestLib macros for checking the correct state
+    // FIXME: use QTestLib macros for checking the correct state
     // start editing
     buffer.startEditing();
 
@@ -55,7 +57,7 @@ void KateTextBufferTest::basicBufferTest()
 void KateTextBufferTest::wrapLineTest()
 {
     // construct an empty text buffer
-    Kate::TextBuffer buffer(0, 1);
+    Kate::TextBuffer buffer(nullptr, 1);
 
     // wrap first empty line -> we should have two empty lines
     buffer.startEditing();
@@ -77,7 +79,7 @@ void KateTextBufferTest::wrapLineTest()
 void KateTextBufferTest::insertRemoveTextTest()
 {
     // construct an empty text buffer
-    Kate::TextBuffer buffer(0, 1);
+    Kate::TextBuffer buffer(nullptr, 1);
 
     // wrap first line
     buffer.startEditing();
@@ -97,8 +99,8 @@ void KateTextBufferTest::insertRemoveTextTest()
     QVERIFY(buffer.text() == QString());
 
     // second text line should be still there
-    //const QString &secondText = second->text ();
-    //QVERIFY (secondText == "")
+    // const QString &secondText = second->text ();
+    // QVERIFY (secondText == "")
 
     // insert text
     buffer.startEditing();
@@ -137,7 +139,7 @@ void KateTextBufferTest::cursorTest()
     // test with different block sizes
     for (int i = 1; i <= 4; ++i) {
         // construct an empty text buffer
-        Kate::TextBuffer buffer(0, i);
+        Kate::TextBuffer buffer(nullptr, i);
 
         // wrap first line
         buffer.startEditing();
@@ -151,16 +153,16 @@ void KateTextBufferTest::cursorTest()
         // construct cursor
         Kate::TextCursor *cursor1 = new Kate::TextCursor(buffer, KTextEditor::Cursor(0, 0), Kate::TextCursor::MoveOnInsert);
         QVERIFY(cursor1->toCursor() == KTextEditor::Cursor(0, 0));
-        //printf ("cursor %d, %d\n", cursor1->line(), cursor1->column());
+        // printf ("cursor %d, %d\n", cursor1->line(), cursor1->column());
 
-        //Kate::TextCursor *cursor2 = new Kate::TextCursor (buffer, KTextEditor::Cursor (1, 8), Kate::TextCursor::MoveOnInsert);
-        //printf ("cursor %d, %d\n", cursor2->line(), cursor2->column());
+        // Kate::TextCursor *cursor2 = new Kate::TextCursor (buffer, KTextEditor::Cursor (1, 8), Kate::TextCursor::MoveOnInsert);
+        // printf ("cursor %d, %d\n", cursor2->line(), cursor2->column());
 
-        //Kate::TextCursor *cursor3 = new Kate::TextCursor (buffer, KTextEditor::Cursor (0, 123), Kate::TextCursor::MoveOnInsert);
-        //printf ("cursor %d, %d\n", cursor3->line(), cursor3->column());
+        // Kate::TextCursor *cursor3 = new Kate::TextCursor (buffer, KTextEditor::Cursor (0, 123), Kate::TextCursor::MoveOnInsert);
+        // printf ("cursor %d, %d\n", cursor3->line(), cursor3->column());
 
-        //Kate::TextCursor *cursor4 = new Kate::TextCursor (buffer, KTextEditor::Cursor (1323, 1), Kate::TextCursor::MoveOnInsert);
-        //printf ("cursor %d, %d\n", cursor4->line(), cursor4->column());
+        // Kate::TextCursor *cursor4 = new Kate::TextCursor (buffer, KTextEditor::Cursor (1323, 1), Kate::TextCursor::MoveOnInsert);
+        // printf ("cursor %d, %d\n", cursor4->line(), cursor4->column());
 
         // insert text
         buffer.startEditing();
@@ -168,7 +170,7 @@ void KateTextBufferTest::cursorTest()
         buffer.finishEditing();
         buffer.debugPrint(QLatin1String("Cursor buffer"));
 
-        //printf ("cursor %d, %d\n", cursor1->line(), cursor1->column());
+        // printf ("cursor %d, %d\n", cursor1->line(), cursor1->column());
         QVERIFY(cursor1->toCursor() == KTextEditor::Cursor(0, 5));
 
         // remove text
@@ -177,7 +179,7 @@ void KateTextBufferTest::cursorTest()
         buffer.finishEditing();
         buffer.debugPrint(QLatin1String("Cursor buffer"));
 
-        //printf ("cursor %d, %d\n", cursor1->line(), cursor1->column());
+        // printf ("cursor %d, %d\n", cursor1->line(), cursor1->column());
         QVERIFY(cursor1->toCursor() == KTextEditor::Cursor(0, 4));
 
         // wrap line
@@ -186,7 +188,7 @@ void KateTextBufferTest::cursorTest()
         buffer.finishEditing();
         buffer.debugPrint(QLatin1String("Cursor buffer"));
 
-        //printf ("cursor %d, %d\n", cursor1->line(), cursor1->column());
+        // printf ("cursor %d, %d\n", cursor1->line(), cursor1->column());
         QVERIFY(cursor1->toCursor() == KTextEditor::Cursor(1, 1));
 
         // unwrap line
@@ -195,7 +197,7 @@ void KateTextBufferTest::cursorTest()
         buffer.finishEditing();
         buffer.debugPrint(QLatin1String("Cursor buffer"));
 
-        //printf ("cursor %d, %d\n", cursor1->line(), cursor1->column());
+        // printf ("cursor %d, %d\n", cursor1->line(), cursor1->column());
         QVERIFY(cursor1->toCursor() == KTextEditor::Cursor(0, 4));
 
         // verify content
@@ -211,7 +213,7 @@ void KateTextBufferTest::cursorTest()
 void KateTextBufferTest::foldingTest()
 {
     // construct an empty text buffer & folding info
-    Kate::TextBuffer buffer(0, 1);
+    Kate::TextBuffer buffer(nullptr, 1);
     Kate::TextFolding folding(buffer);
 
     // insert some text
@@ -266,7 +268,7 @@ void KateTextBufferTest::foldingTest()
     }
 
     // there shall be one range starting at 5
-    QVector<QPair<qint64, Kate::TextFolding::FoldingRangeFlags> > forLine = folding.foldingRangesStartingOnLine(5);
+    QVector<QPair<qint64, Kate::TextFolding::FoldingRangeFlags>> forLine = folding.foldingRangesStartingOnLine(5);
     QVERIFY(forLine.size() == 1);
     QVERIFY(forLine[0].first == 0);
     QVERIFY(forLine[0].second & Kate::TextFolding::Folded);
@@ -398,13 +400,12 @@ void KateTextBufferTest::foldingTest()
     // restore state
     folding.importFoldingRanges(folds);
     QVERIFY(folding.debugDump() == textDump);
-
 }
 
 void KateTextBufferTest::nestedFoldingTest()
 {
     // construct an empty text buffer & folding info
-    Kate::TextBuffer buffer(0, 1);
+    Kate::TextBuffer buffer(nullptr, 1);
     Kate::TextFolding folding(buffer);
 
     // insert two nested folds in 5 lines
@@ -443,7 +444,7 @@ void KateTextBufferTest::saveFileInUnwritableFolder()
 
     QFile::setPermissions(folder_name, QFile::ExeOwner);
 
-    Kate::TextBuffer buffer(0, 1);
+    Kate::TextBuffer buffer(nullptr, 1);
     buffer.setTextCodec(QTextCodec::codecForName("UTF-8"));
     buffer.setFallbackTextCodec(QTextCodec::codecForName("UTF-8"));
     bool a, b;
@@ -464,3 +465,37 @@ void KateTextBufferTest::saveFileInUnwritableFolder()
     QVERIFY(f.remove());
     QVERIFY(dir.remove());
 }
+
+void KateTextBufferTest::saveFileWithElevatedPrivileges()
+{
+    // create temp dir and get file name inside
+    QTemporaryDir dir;
+    QVERIFY(dir.isValid());
+    const QString file_path = dir.path() + QLatin1String("/foo");
+
+    QFile f(file_path);
+    QVERIFY(f.open(QIODevice::WriteOnly | QIODevice::Truncate));
+    f.write("1234567890");
+    QVERIFY(f.flush());
+    f.close();
+
+    Kate::TextBuffer buffer(nullptr, 1, true);
+    buffer.setTextCodec(QTextCodec::codecForName("UTF-8"));
+    buffer.setFallbackTextCodec(QTextCodec::codecForName("UTF-8"));
+    bool a, b;
+    int c;
+    buffer.load(file_path, a, b, c, true);
+    buffer.clear();
+    buffer.startEditing();
+    buffer.insertText(KTextEditor::Cursor(0, 0), QLatin1String("ABC"));
+    buffer.finishEditing();
+    qDebug() << buffer.text();
+    buffer.save(file_path);
+
+    f.open(QIODevice::ReadOnly);
+    QCOMPARE(f.readAll(), QByteArray("ABC"));
+    f.close();
+
+    QVERIFY(f.remove());
+    QVERIFY(dir.remove());
+}
