@@ -18,7 +18,6 @@
  * Boston, MA 02110-1301, USA.
  */
 
-
 #include <katecompletionwidget.h>
 #include <kateconfig.h>
 #include <kateglobal.h>
@@ -32,10 +31,9 @@
 using namespace KTextEditor;
 using KateVi::Mappings;
 
-
 QTEST_MAIN(CompletionTest)
 
-//BEGIN: VimCodeCompletionTestModel
+// BEGIN: VimCodeCompletionTestModel
 
 VimCodeCompletionTestModel::VimCodeCompletionTestModel(KTextEditor::View *parent)
     : KTextEditor::CodeCompletionModel(parent)
@@ -50,7 +48,7 @@ VimCodeCompletionTestModel::VimCodeCompletionTestModel(KTextEditor::View *parent
 QVariant VimCodeCompletionTestModel::data(const QModelIndex &index, int role) const
 {
     // Order is important, here, as the completion widget seems to do its own sorting.
-    const char *completions[] = { "completion1", "completion2", "completion3" };
+    const char *completions[] = {"completion1", "completion2", "completion3"};
     if (role == Qt::DisplayRole) {
         if (index.column() == Name) {
             return QString(completions[index.row()]);
@@ -59,14 +57,14 @@ QVariant VimCodeCompletionTestModel::data(const QModelIndex &index, int role) co
     return QVariant();
 }
 
-CodeCompletionInterface * VimCodeCompletionTestModel::cc() const
+CodeCompletionInterface *VimCodeCompletionTestModel::cc() const
 {
     return dynamic_cast<CodeCompletionInterface *>(const_cast<QObject *>(QObject::parent()));
 }
 
-//END: VimCodeCompletionTestModel
+// END: VimCodeCompletionTestModel
 
-//BEGIN: CodeCompletionInterface
+// BEGIN: CodeCompletionInterface
 
 FailTestOnInvocationModel::FailTestOnInvocationModel(KTextEditor::View *parent)
     : KTextEditor::CodeCompletionModel(parent)
@@ -92,24 +90,24 @@ void FailTestOnInvocationModel::failTest() const
     QFAIL("Shouldn't be invoking me!");
 }
 
-CodeCompletionInterface * FailTestOnInvocationModel::cc() const
+CodeCompletionInterface *FailTestOnInvocationModel::cc() const
 {
     return dynamic_cast<CodeCompletionInterface *>(const_cast<QObject *>(QObject::parent()));
 }
 
-//END: CodeCompletionInterface
+// END: CodeCompletionInterface
 
-//BEGIN: CompletionTest
+// BEGIN: CompletionTest
 
 void CompletionTest::FakeCodeCompletionTests()
 {
     // Test that FakeCodeCompletionTestModel behaves similar to the code-completion in e.g. KDevelop.
     const bool oldStealKeys = KateViewConfig::global()->viInputModeStealKeys();
-    KateViewConfig::global()->setViInputModeStealKeys(true); // For Ctrl-P, Ctrl-N etc
-    ensureKateViewVisible(); // KTextEditor::ViewPrivate needs to be visible for the completion widget.
+    KateViewConfig::global()->setValue(KateViewConfig::ViInputModeStealKeys, true); // For Ctrl-P, Ctrl-N etc
+    ensureKateViewVisible();                                                        // KTextEditor::ViewPrivate needs to be visible for the completion widget.
     FakeCodeCompletionTestModel *fakeCodeCompletionModel = new FakeCodeCompletionTestModel(kate_view);
     kate_view->registerCompletionModel(fakeCodeCompletionModel);
-    fakeCodeCompletionModel->setCompletions(QStringList() << "completionA" << "completionB" << "completionC");
+    fakeCodeCompletionModel->setCompletions({"completionA", "completionB", "completionC"});
     DoTest("", "i\\ctrl-p\\enter", "completionC");
     DoTest("", "i\\ctrl-p\\ctrl-p\\enter", "completionB");
     DoTest("", "i\\ctrl-p\\ctrl-p\\ctrl-p\\enter", "completionA");
@@ -134,7 +132,7 @@ void CompletionTest::FakeCodeCompletionTests()
     QCOMPARE(m_docChanges[1].newText(), QString("completionA"));
     FinishTest("completionA");
     // A "word" is currently alphanumeric, plus underscore.
-    fakeCodeCompletionModel->setCompletions(QStringList() << "w_123completion");
+    fakeCodeCompletionModel->setCompletions({"w_123completion"});
     BeginTest("(w_123");
     TestPressKey("ea");
     clearTrackedDocumentChanges();
@@ -181,7 +179,7 @@ void CompletionTest::FakeCodeCompletionTests()
     // is added as "function()", and the cursor placed after the closing ")".
     // The addition of "function()" is done in two steps: first "function", then "()".
     BeginTest("object->");
-    fakeCodeCompletionModel->setCompletions(QStringList() << "functionCall()");
+    fakeCodeCompletionModel->setCompletions({"functionCall()"});
     fakeCodeCompletionModel->setRemoveTailOnComplete(true);
     clearTrackedDocumentChanges();
     TestPressKey("$a\\ctrl- \\enter");
@@ -199,7 +197,7 @@ void CompletionTest::FakeCodeCompletionTests()
     // The addition of "function()" is done in two steps: first "function", then "()".
     qDebug() << "Fleep";
     BeginTest("object->");
-    fakeCodeCompletionModel->setCompletions(QStringList() << "functionCall(...)");
+    fakeCodeCompletionModel->setCompletions({"functionCall(...)"});
     fakeCodeCompletionModel->setRemoveTailOnComplete(true);
     clearTrackedDocumentChanges();
     TestPressKey("$a\\ctrl- \\enter");
@@ -219,7 +217,7 @@ void CompletionTest::FakeCodeCompletionTests()
     // in contrast to the case where there is no opening bracket after the cursor.
     // No brackets are added.  No removals occur if there is no word before the cursor.
     BeginTest("object->(");
-    fakeCodeCompletionModel->setCompletions(QStringList() << "functionCall()");
+    fakeCodeCompletionModel->setCompletions({"functionCall()"});
     fakeCodeCompletionModel->setRemoveTailOnComplete(true);
     clearTrackedDocumentChanges();
     TestPressKey("f(i\\ctrl- \\enter");
@@ -232,7 +230,7 @@ void CompletionTest::FakeCodeCompletionTests()
 
     // There can't be any non-whitespace between cursor position and opening bracket, though!
     BeginTest("object->|(   (");
-    fakeCodeCompletionModel->setCompletions(QStringList() << "functionCall()");
+    fakeCodeCompletionModel->setCompletions({"functionCall()"});
     fakeCodeCompletionModel->setRemoveTailOnComplete(true);
     clearTrackedDocumentChanges();
     TestPressKey("f>a\\ctrl- \\enter");
@@ -247,7 +245,7 @@ void CompletionTest::FakeCodeCompletionTests()
 
     // Whitespace before the bracket is fine, though.
     BeginTest("object->    (<-Cursor here!");
-    fakeCodeCompletionModel->setCompletions(QStringList() << "functionCall()");
+    fakeCodeCompletionModel->setCompletions({"functionCall()"});
     fakeCodeCompletionModel->setRemoveTailOnComplete(true);
     clearTrackedDocumentChanges();
     TestPressKey("f>a\\ctrl- \\enter");
@@ -260,7 +258,7 @@ void CompletionTest::FakeCodeCompletionTests()
 
     // Be careful with positioning the cursor if we delete leading text!
     BeginTest("object->    (<-Cursor here!");
-    fakeCodeCompletionModel->setCompletions(QStringList() << "functionCall()");
+    fakeCodeCompletionModel->setCompletions({"functionCall()"});
     fakeCodeCompletionModel->setRemoveTailOnComplete(true);
     clearTrackedDocumentChanges();
     TestPressKey("f>afunct");
@@ -278,7 +276,7 @@ void CompletionTest::FakeCodeCompletionTests()
     // If we're removing tail on complete, it's whether there is a suitable opening
     // bracket *after* the word (not the cursor) that's important.
     BeginTest("object->function    (<-Cursor here!");
-    fakeCodeCompletionModel->setCompletions(QStringList() << "functionCall()");
+    fakeCodeCompletionModel->setCompletions({"functionCall()"});
     fakeCodeCompletionModel->setRemoveTailOnComplete(true);
     clearTrackedDocumentChanges();
     TestPressKey("12li"); // Start inserting before the "t" in "function"
@@ -298,7 +296,7 @@ void CompletionTest::FakeCodeCompletionTests()
 
     // Repeat of bracket-merging stuff, this time for functions that take at least one argument.
     BeginTest("object->(");
-    fakeCodeCompletionModel->setCompletions(QStringList() << "functionCall(...)");
+    fakeCodeCompletionModel->setCompletions({"functionCall(...)"});
     fakeCodeCompletionModel->setRemoveTailOnComplete(true);
     clearTrackedDocumentChanges();
     TestPressKey("f(i\\ctrl- \\enter");
@@ -312,7 +310,7 @@ void CompletionTest::FakeCodeCompletionTests()
 
     // There can't be any non-whitespace between cursor position and opening bracket, though!
     BeginTest("object->|(   (");
-    fakeCodeCompletionModel->setCompletions(QStringList() << "functionCall(...)");
+    fakeCodeCompletionModel->setCompletions({"functionCall(...)"});
     fakeCodeCompletionModel->setRemoveTailOnComplete(true);
     clearTrackedDocumentChanges();
     TestPressKey("f>a\\ctrl- \\enter");
@@ -328,7 +326,7 @@ void CompletionTest::FakeCodeCompletionTests()
     // Whitespace before the bracket is fine, though.
     BeginTest("object->    (<-Cursor here!");
     qDebug() << "NooooO";
-    fakeCodeCompletionModel->setCompletions(QStringList() << "functionCall(...)");
+    fakeCodeCompletionModel->setCompletions({"functionCall(...)"});
     fakeCodeCompletionModel->setRemoveTailOnComplete(true);
     clearTrackedDocumentChanges();
     TestPressKey("f>a\\ctrl- \\enter");
@@ -341,7 +339,7 @@ void CompletionTest::FakeCodeCompletionTests()
 
     // Be careful with positioning the cursor if we delete leading text!
     BeginTest("object->    (<-Cursor here!");
-    fakeCodeCompletionModel->setCompletions(QStringList() << "functionCall(...)");
+    fakeCodeCompletionModel->setCompletions({"functionCall(...)"});
     fakeCodeCompletionModel->setRemoveTailOnComplete(true);
     clearTrackedDocumentChanges();
     TestPressKey("f>afunct");
@@ -359,7 +357,7 @@ void CompletionTest::FakeCodeCompletionTests()
     // If we're removing tail on complete, it's whether there is a suitable opening
     // bracket *after* the word (not the cursor) that's important.
     BeginTest("object->function    (<-Cursor here!");
-    fakeCodeCompletionModel->setCompletions(QStringList() << "functionCall(...)");
+    fakeCodeCompletionModel->setCompletions({"functionCall(...)"});
     fakeCodeCompletionModel->setRemoveTailOnComplete(true);
     clearTrackedDocumentChanges();
     TestPressKey("12li"); // Start inserting before the "t" in "function"
@@ -379,7 +377,7 @@ void CompletionTest::FakeCodeCompletionTests()
 
     // Deal with function completions which add a ";".
     BeginTest("");
-    fakeCodeCompletionModel->setCompletions(QStringList() << "functionCall();");
+    fakeCodeCompletionModel->setCompletions({"functionCall();"});
     clearTrackedDocumentChanges();
     TestPressKey("ifun");
     clearTrackedDocumentChanges();
@@ -396,12 +394,12 @@ void CompletionTest::FakeCodeCompletionTests()
     FinishTest("functionCall();");
 
     BeginTest("");
-    fakeCodeCompletionModel->setCompletions(QStringList() << "functionCall();");
+    fakeCodeCompletionModel->setCompletions({"functionCall();"});
     TestPressKey("ifun\\ctrl- \\enterX");
     FinishTest("functionCall();X");
 
     BeginTest("");
-    fakeCodeCompletionModel->setCompletions(QStringList() << "functionCall(...);");
+    fakeCodeCompletionModel->setCompletions({"functionCall(...);"});
     clearTrackedDocumentChanges();
     TestPressKey("ifun");
     clearTrackedDocumentChanges();
@@ -418,21 +416,21 @@ void CompletionTest::FakeCodeCompletionTests()
     FinishTest("functionCall();");
 
     BeginTest("");
-    fakeCodeCompletionModel->setCompletions(QStringList() << "functionCall(...);");
+    fakeCodeCompletionModel->setCompletions({"functionCall(...);"});
     TestPressKey("ifun\\ctrl- \\enterX");
     FinishTest("functionCall(X);");
 
     // Completions ending with ";" do not participate in bracket merging.
     BeginTest("(<-old bracket");
-    fakeCodeCompletionModel->setCompletions(QStringList() << "functionCall();");
+    fakeCodeCompletionModel->setCompletions({"functionCall();"});
     TestPressKey("ifun\\ctrl- \\enterX");
     FinishTest("functionCall();X(<-old bracket");
     BeginTest("(<-old bracket");
-    fakeCodeCompletionModel->setCompletions(QStringList() << "functionCall(...);");
+    fakeCodeCompletionModel->setCompletions({"functionCall(...);"});
     TestPressKey("ifun\\ctrl- \\enterX");
     FinishTest("functionCall(X);(<-old bracket");
 
-    KateViewConfig::global()->setViInputModeStealKeys(oldStealKeys);
+    KateViewConfig::global()->setValue(KateViewConfig::ViInputModeStealKeys, oldStealKeys);
     kate_view->hide();
     mainWindow->hide();
     kate_view->unregisterCompletionModel(fakeCodeCompletionModel);
@@ -443,10 +441,10 @@ void CompletionTest::CompletionTests()
 {
     const bool oldRemoveTailOnCompletion = KateViewConfig::global()->wordCompletionRemoveTail();
     // For these tests, assume we don't swallow the tail on completion.
-    KateViewConfig::global()->setWordCompletionRemoveTail(false);
+    KateViewConfig::global()->setValue(KateViewConfig::WordCompletionRemoveTail, false);
 
-    KateViewConfig::global()->setViInputModeStealKeys(true); // For Ctrl-P, Ctrl-N etc
-    ensureKateViewVisible(); // KTextEditor::ViewPrivate needs to be visible for the completion widget.
+    KateViewConfig::global()->setValue(KateViewConfig::ViInputModeStealKeys, true); // For Ctrl-P, Ctrl-N etc
+    ensureKateViewVisible();                                                        // KTextEditor::ViewPrivate needs to be visible for the completion widget.
     VimCodeCompletionTestModel *testModel = new VimCodeCompletionTestModel(kate_view);
 
     BeginTest("");
@@ -554,23 +552,23 @@ void CompletionTest::CompletionTests()
     // i.e. fairly intelligently :)
     FakeCodeCompletionTestModel *fakeCodeCompletionModel = new FakeCodeCompletionTestModel(kate_view);
     fakeCodeCompletionModel->setRemoveTailOnComplete(true);
-    KateViewConfig::global()->setWordCompletionRemoveTail(true);
+    KateViewConfig::global()->setValue(KateViewConfig::WordCompletionRemoveTail, true);
     kate_view->registerCompletionModel(fakeCodeCompletionModel);
     clearAllMacros();
     BeginTest("funct\nnoa\ncomtail\ncomtail");
-    fakeCodeCompletionModel->setCompletions(QStringList() << "completionA" << "functionwithargs(...)" << "noargfunction()");
+    fakeCodeCompletionModel->setCompletions({"completionA", "functionwithargs(...)", "noargfunction()"});
     fakeCodeCompletionModel->setFailTestOnInvocation(false);
     // Record 'a'.
     TestPressKey("i\\right\\right\\right\\right\\right\\ctrl- \\enterfirstArg"); // Function with args.
     TestPressKey("\\home\\down\\right\\right\\right\\ctrl- \\enter");            // Function no args.
     fakeCodeCompletionModel->setRemoveTailOnComplete(true);
-    KateViewConfig::global()->setWordCompletionRemoveTail(true);
-    TestPressKey("\\home\\down\\right\\right\\right\\ctrl- \\enter");   // Cut off tail.
+    KateViewConfig::global()->setValue(KateViewConfig::WordCompletionRemoveTail, true);
+    TestPressKey("\\home\\down\\right\\right\\right\\ctrl- \\enter"); // Cut off tail.
     fakeCodeCompletionModel->setRemoveTailOnComplete(false);
-    KateViewConfig::global()->setWordCompletionRemoveTail(false);
-    TestPressKey("\\home\\down\\right\\right\\right\\ctrl- \\enter\\ctrl-c");   // Don't cut off tail.
+    KateViewConfig::global()->setValue(KateViewConfig::WordCompletionRemoveTail, false);
+    TestPressKey("\\home\\down\\right\\right\\right\\ctrl- \\enter\\ctrl-c"); // Don't cut off tail.
     fakeCodeCompletionModel->setRemoveTailOnComplete(true);
-    KateViewConfig::global()->setWordCompletionRemoveTail(true);
+    KateViewConfig::global()->setValue(KateViewConfig::WordCompletionRemoveTail, true);
     // Replay.
     fakeCodeCompletionModel->setFailTestOnInvocation(true);
     kate_document->setText("funct\nnoa\ncomtail\ncomtail");
@@ -579,10 +577,10 @@ void CompletionTest::CompletionTests()
 
     // Clear our log of completions for each change.
     BeginTest("");
-    fakeCodeCompletionModel->setCompletions(QStringList() << "completionA");
+    fakeCodeCompletionModel->setCompletions({"completionA"});
     fakeCodeCompletionModel->setFailTestOnInvocation(false);
     TestPressKey("ciw\\ctrl- \\enter\\ctrl-c");
-    fakeCodeCompletionModel->setCompletions(QStringList() << "completionB");
+    fakeCodeCompletionModel->setCompletions({"completionB"});
     TestPressKey("ciw\\ctrl- \\enter\\ctrl-c");
     fakeCodeCompletionModel->setFailTestOnInvocation(true);
     TestPressKey(".");
@@ -590,7 +588,7 @@ void CompletionTest::CompletionTests()
 
     kate_view->unregisterCompletionModel(fakeCodeCompletionModel);
     delete fakeCodeCompletionModel;
-    KateViewConfig::global()->setWordCompletionRemoveTail(oldRemoveTailOnCompletion);
+    KateViewConfig::global()->setValue(KateViewConfig::WordCompletionRemoveTail, oldRemoveTailOnCompletion);
 
     // Hide the kate_view for subsequent tests.
     kate_view->hide();
@@ -607,4 +605,4 @@ void CompletionTest::clearTrackedDocumentChanges()
     m_docChanges.clear();
 }
 
-//END: CompletionTest
+// END: CompletionTest
