@@ -26,13 +26,12 @@
 
 namespace Kate
 {
-
 TextRange::TextRange(TextBuffer &buffer, const KTextEditor::Range &range, InsertBehaviors insertBehavior, EmptyBehavior emptyBehavior)
     : m_buffer(buffer)
-    , m_start(buffer, this, range.start(), (insertBehavior &ExpandLeft) ? Kate::TextCursor::StayOnInsert : Kate::TextCursor::MoveOnInsert)
-    , m_end(buffer, this, range.end(), (insertBehavior &ExpandRight) ? Kate::TextCursor::MoveOnInsert : Kate::TextCursor::StayOnInsert)
-    , m_view(0)
-    , m_feedback(0)
+    , m_start(buffer, this, range.start(), (insertBehavior & ExpandLeft) ? Kate::TextCursor::StayOnInsert : Kate::TextCursor::MoveOnInsert)
+    , m_end(buffer, this, range.end(), (insertBehavior & ExpandRight) ? Kate::TextCursor::MoveOnInsert : Kate::TextCursor::StayOnInsert)
+    , m_view(nullptr)
+    , m_feedback(nullptr)
     , m_zDepth(0.0)
     , m_attributeOnlyForViews(false)
     , m_invalidateIfEmpty(emptyBehavior == InvalidateIfEmpty)
@@ -49,7 +48,7 @@ TextRange::~TextRange()
     /**
      * reset feedback, don't want feedback during destruction
      */
-    m_feedback = 0;
+    m_feedback = nullptr;
 
     // remove range from m_ranges
     fixLookup(m_start.line(), m_end.line(), -1, -1);
@@ -181,6 +180,11 @@ void TextRange::setRange(const KTextEditor::Range &range)
 
 void TextRange::checkValidity(int oldStartLine, int oldEndLine, bool notifyAboutChange)
 {
+    /**
+     * in any case: reset the flag, to avoid multiple runs
+     */
+    m_isCheckValidityRequired = false;
+
     /**
      * check if any cursor is invalid or the range is zero size and it should be invalidated then
      */
@@ -279,7 +283,7 @@ void TextRange::setView(KTextEditor::View *view)
      * notify all views (can be optimized later)
      */
     if (m_attribute || m_feedback) {
-        m_buffer.notifyAboutRangeChange(0, m_start.line(), m_end.line(), m_attribute);
+        m_buffer.notifyAboutRangeChange(nullptr, m_start.line(), m_end.line(), m_attribute);
     }
 }
 
