@@ -20,7 +20,7 @@
 #include "kateviewinternal.h"
 #include "kateconfig.h"
 #include <vimode/inputmodemanager.h>
-#include <vimode/emulatedcommandbar.h>
+#include <vimode/emulatedcommandbar/emulatedcommandbar.h>
 #include <vimode/modes/replacevimode.h>
 #include <vimode/modes/visualvimode.h>
 #include <vimode/marks.h>
@@ -31,40 +31,42 @@
 
 #include <QCoreApplication>
 
-namespace {
-    QString viModeToString(KateVi::ViMode mode)
-    {
-        QString modeStr;
-        switch (mode) {
-            case KateVi::InsertMode:
-                modeStr = i18n("VI: INSERT MODE");
-                break;
-            case KateVi::NormalMode:
-                modeStr = i18n("VI: NORMAL MODE");
-                break;
-            case KateVi::VisualMode:
-                modeStr = i18n("VI: VISUAL");
-                break;
-            case KateVi::VisualBlockMode:
-                modeStr = i18n("VI: VISUAL BLOCK");
-                break;
-            case KateVi::VisualLineMode:
-                modeStr = i18n("VI: VISUAL LINE");
-                break;
-            case KateVi::ReplaceMode:
-                modeStr = i18n("VI: REPLACE");
-                break;
-        }
-
-        return modeStr;
+namespace
+{
+QString viModeToString(KateVi::ViMode mode)
+{
+    QString modeStr;
+    switch (mode) {
+        case KateVi::InsertMode:
+            modeStr = i18n("VI: INSERT MODE");
+            break;
+        case KateVi::NormalMode:
+            modeStr = i18n("VI: NORMAL MODE");
+            break;
+        case KateVi::VisualMode:
+            modeStr = i18n("VI: VISUAL");
+            break;
+        case KateVi::VisualBlockMode:
+            modeStr = i18n("VI: VISUAL BLOCK");
+            break;
+        case KateVi::VisualLineMode:
+            modeStr = i18n("VI: VISUAL LINE");
+            break;
+        case KateVi::ReplaceMode:
+            modeStr = i18n("VI: REPLACE");
+            break;
     }
+
+    return modeStr;
+}
 }
 
 KateViInputMode::KateViInputMode(KateViewInternal *viewInternal, KateVi::GlobalState *global)
     : KateAbstractInputMode(viewInternal)
-    , m_viModeEmulatedCommandBar(0)
+    , m_viModeEmulatedCommandBar(nullptr)
     , m_viGlobal(global)
     , m_caret(KateRenderer::Block)
+    , m_nextKeypressIsOverriddenShortCut(false)
     , m_activated(false)
 {
     m_relLineNumbers = KateViewConfig::global()->viRelativeLineNumbers();
@@ -80,7 +82,7 @@ void KateViInputMode::activate()
 {
     m_activated = true;
     setCaretStyle(KateRenderer::Block); // TODO: can we end up in insert mode?
-    reset(); // TODO: is this necessary? (well, not anymore I guess)
+    reset();                            // TODO: is this necessary? (well, not anymore I guess)
 
     if (view()->selection()) {
         m_viModeManager->changeViMode(KateVi::VisualMode);
@@ -96,7 +98,7 @@ void KateViInputMode::deactivate()
         m_viModeEmulatedCommandBar->hideMe();
     }
 
-    // make sure to turn off edits mergin when leaving vi input mode
+    // make sure to turn off edits merging when leaving vi input mode
     view()->doc()->setUndoMergeAllEdits(false);
     m_activated = false;
     viewInternal()->iconBorder()->setRelLineNumbersOn(false);
@@ -118,7 +120,7 @@ void KateViInputMode::reset()
 
 bool KateViInputMode::overwrite() const
 {
-    return  m_viModeManager->getCurrentViMode() == KateVi::ViMode::ReplaceMode;
+    return m_viModeManager->getCurrentViMode() == KateVi::ViMode::ReplaceMode;
 }
 
 void KateViInputMode::overwrittenChar(const QChar &c)
@@ -131,11 +133,20 @@ void KateViInputMode::clearSelection()
     // do nothing, handled elsewhere
 }
 
-bool KateViInputMode::stealKey(const QKeyEvent *k) const
+bool KateViInputMode::stealKey(QKeyEvent *k)
 {
-    const bool steal = KateViewConfig::global()->viInputModeStealKeys();
-    return steal && (m_viModeManager->getCurrentViMode() != KateVi::ViMode::InsertMode ||
-                        k->modifiers() == Qt::ControlModifier || k->key() == Qt::Key_Insert);
+    if (!KateViewConfig::global()->viInputModeStealKeys()) {
+        return false;
+    }
+
+    // Actually see if we can make use of this key - if so, we've stolen it; if not,
+    // let Qt's shortcut handling system deal with it.
+    const bool stolen = keyPress(k);
+    if (stolen) {
+        // Qt will replay this QKeyEvent, next time as an ordinary KeyPress.
+        m_nextKeypressIsOverriddenShortCut = true;
+    }
+    return stolen;
 }
 
 KTextEditor::View::InputMode KateViInputMode::viewInputMode() const
@@ -158,15 +169,15 @@ QString KateViInputMode::viewModeHuman() const
     QString currentMode = viModeToString(m_viModeManager->getCurrentViMode());
 
     if (m_viModeManager->macroRecorder()->isRecording()) {
-        currentMode.prepend(QLatin1String("(") + i18n("recording") + QLatin1String(") "));
+        currentMode.prepend(QLatin1Char('(') + i18n("recording") + QLatin1String(") "));
     }
 
     QString cmd = m_viModeManager->getVerbatimKeys();
     if (!cmd.isEmpty()) {
-        currentMode.prepend(QStringLiteral("<em>%1</em> ").arg(cmd));
+        currentMode.prepend(QStringLiteral("%1 ").arg(cmd));
     }
 
-    return QStringLiteral("<b>%1</b>").arg(currentMode);
+    return currentMode;
 }
 
 void KateViInputMode::gotFocus()
@@ -255,7 +266,7 @@ void KateViInputMode::showViModeEmulatedCommandBar()
 KateVi::EmulatedCommandBar *KateViInputMode::viModeEmulatedCommandBar()
 {
     if (!m_viModeEmulatedCommandBar) {
-        m_viModeEmulatedCommandBar = new KateVi::EmulatedCommandBar(m_viModeManager, view());
+        m_viModeEmulatedCommandBar = new KateVi::EmulatedCommandBar(this, m_viModeManager, view());
         m_viModeEmulatedCommandBar->hide();
     }
 
@@ -269,24 +280,14 @@ void KateViInputMode::updateRendererConfig()
 
 bool KateViInputMode::keyPress(QKeyEvent *e)
 {
-    if (m_viModeManager->getCurrentViMode() == KateVi::InsertMode ||
-        m_viModeManager->getCurrentViMode() == KateVi::ReplaceMode) {
+    if (m_nextKeypressIsOverriddenShortCut) {
+        // This is just the replay of a shortcut that we stole, this time as a QKeyEvent.
+        // Ignore it, as we'll have already handled it via stealKey()!
+        m_nextKeypressIsOverriddenShortCut = false;
+        return true;
+    }
 
-        if (m_viModeManager->handleKeypress(e)) {
-            return true;
-        } else if (e->modifiers() != Qt::NoModifier && e->modifiers() != Qt::ShiftModifier) {
-            // re-post key events not handled if they have a modifier other than shift
-            QEvent *copy = new QKeyEvent(e->type(), e->key(), e->modifiers(), e->text(),
-                                         e->isAutoRepeat(), e->count());
-            QCoreApplication::postEvent(viewInternal()->parent(), copy);
-        }
-    } else { // !InsertMode
-        if (!m_viModeManager->handleKeypress(e)) {
-            // we didn't need that keypress, un-steal it :-)
-            QEvent *copy = new QKeyEvent(e->type(), e->key(), e->modifiers(), e->text(),
-                                            e->isAutoRepeat(), e->count());
-            QCoreApplication::postEvent(viewInternal()->parent(), copy);
-        }
+    if (m_viModeManager->handleKeypress(e)) {
         emit view()->viewModeChanged(view(), viewMode());
         return true;
     }
