@@ -29,19 +29,18 @@
 #include "katebuffer.h"
 #include "katepartdebug.h"
 
-namespace {
-
+namespace
+{
 bool enableLayoutCache = false;
 
-bool lessThan(const KateLineLayoutMap::LineLayoutPair &lhs,
-              const KateLineLayoutMap::LineLayoutPair &rhs)
+bool lessThan(const KateLineLayoutMap::LineLayoutPair &lhs, const KateLineLayoutMap::LineLayoutPair &rhs)
 {
     return lhs.first < rhs.first;
 }
 
 }
 
-//BEGIN KateLineLayoutMap
+// BEGIN KateLineLayoutMap
 KateLineLayoutMap::KateLineLayoutMap()
 {
 }
@@ -57,16 +56,13 @@ void KateLineLayoutMap::clear()
 
 bool KateLineLayoutMap::contains(int i) const
 {
-    LineLayoutMap::const_iterator it =
-        qBinaryFind(m_lineLayouts.constBegin(), m_lineLayouts.constEnd(), LineLayoutPair(i, KateLineLayoutPtr()), lessThan);
-    return (it != m_lineLayouts.constEnd());
+    return std::binary_search(m_lineLayouts.constBegin(), m_lineLayouts.constEnd(), LineLayoutPair(i, KateLineLayoutPtr()), lessThan);
 }
 
 void KateLineLayoutMap::insert(int realLine, const KateLineLayoutPtr &lineLayoutPtr)
 {
-    LineLayoutMap::iterator it =
-        qBinaryFind(m_lineLayouts.begin(), m_lineLayouts.end(), LineLayoutPair(realLine, KateLineLayoutPtr()), lessThan);
-    if (it != m_lineLayouts.end()) {
+    LineLayoutMap::iterator it = std::lower_bound(m_lineLayouts.begin(), m_lineLayouts.end(), LineLayoutPair(realLine, KateLineLayoutPtr()), lessThan);
+    if (it != m_lineLayouts.end() && (*it) == LineLayoutPair(realLine, KateLineLayoutPtr())) {
         (*it).second = lineLayoutPtr;
     } else {
         it = std::upper_bound(m_lineLayouts.begin(), m_lineLayouts.end(), LineLayoutPair(realLine, KateLineLayoutPtr()), lessThan);
@@ -88,8 +84,7 @@ void KateLineLayoutMap::viewWidthDecreased(int newWidth)
 {
     LineLayoutMap::iterator it = m_lineLayouts.begin();
     for (; it != m_lineLayouts.end(); ++it) {
-        if ((*it).second->isValid()
-                && ((*it).second->viewLineCount() > 1 || (*it).second->width() > newWidth)) {
+        if ((*it).second->isValid() && ((*it).second->viewLineCount() > 1 || (*it).second->width() > newWidth)) {
             (*it).second->invalidateLayout();
         }
     }
@@ -97,10 +92,8 @@ void KateLineLayoutMap::viewWidthDecreased(int newWidth)
 
 void KateLineLayoutMap::relayoutLines(int startRealLine, int endRealLine)
 {
-    LineLayoutMap::iterator start =
-        std::lower_bound(m_lineLayouts.begin(), m_lineLayouts.end(), LineLayoutPair(startRealLine, KateLineLayoutPtr()), lessThan);
-    LineLayoutMap::iterator end =
-        std::upper_bound(start, m_lineLayouts.end(), LineLayoutPair(endRealLine, KateLineLayoutPtr()), lessThan);
+    LineLayoutMap::iterator start = std::lower_bound(m_lineLayouts.begin(), m_lineLayouts.end(), LineLayoutPair(startRealLine, KateLineLayoutPtr()), lessThan);
+    LineLayoutMap::iterator end = std::upper_bound(start, m_lineLayouts.end(), LineLayoutPair(endRealLine, KateLineLayoutPtr()), lessThan);
 
     while (start != end) {
         (*start).second->setLayoutDirty();
@@ -110,10 +103,8 @@ void KateLineLayoutMap::relayoutLines(int startRealLine, int endRealLine)
 
 void KateLineLayoutMap::slotEditDone(int fromLine, int toLine, int shiftAmount)
 {
-    LineLayoutMap::iterator start =
-        std::lower_bound(m_lineLayouts.begin(), m_lineLayouts.end(), LineLayoutPair(fromLine, KateLineLayoutPtr()), lessThan);
-    LineLayoutMap::iterator end =
-        std::upper_bound(start, m_lineLayouts.end(), LineLayoutPair(toLine, KateLineLayoutPtr()), lessThan);
+    LineLayoutMap::iterator start = std::lower_bound(m_lineLayouts.begin(), m_lineLayouts.end(), LineLayoutPair(fromLine, KateLineLayoutPtr()), lessThan);
+    LineLayoutMap::iterator end = std::upper_bound(start, m_lineLayouts.end(), LineLayoutPair(toLine, KateLineLayoutPtr()), lessThan);
     LineLayoutMap::iterator it;
 
     if (shiftAmount != 0) {
@@ -136,11 +127,11 @@ void KateLineLayoutMap::slotEditDone(int fromLine, int toLine, int shiftAmount)
 
 KateLineLayoutPtr &KateLineLayoutMap::operator[](int i)
 {
-    LineLayoutMap::iterator it =
-        qBinaryFind(m_lineLayouts.begin(), m_lineLayouts.end(), LineLayoutPair(i, KateLineLayoutPtr()), lessThan);
+    const LineLayoutMap::iterator it = std::lower_bound(m_lineLayouts.begin(), m_lineLayouts.end(), LineLayoutPair(i, KateLineLayoutPtr()), lessThan);
+    Q_ASSERT(it != m_lineLayouts.end());
     return (*it).second;
 }
-//END KateLineLayoutMap
+// END KateLineLayoutMap
 
 KateLayoutCache::KateLayoutCache(KateRenderer *renderer, QObject *parent)
     : QObject(parent)
@@ -157,13 +148,13 @@ KateLayoutCache::KateLayoutCache(KateRenderer *renderer, QObject *parent)
      */
     connect(&m_renderer->doc()->buffer(), SIGNAL(lineWrapped(KTextEditor::Cursor)), this, SLOT(wrapLine(KTextEditor::Cursor)));
     connect(&m_renderer->doc()->buffer(), SIGNAL(lineUnwrapped(int)), this, SLOT(unwrapLine(int)));
-    connect(&m_renderer->doc()->buffer(), SIGNAL(textInserted(KTextEditor::Cursor,QString)), this, SLOT(insertText(KTextEditor::Cursor,QString)));
-    connect(&m_renderer->doc()->buffer(), SIGNAL(textRemoved(KTextEditor::Range,QString)), this, SLOT(removeText(KTextEditor::Range)));
+    connect(&m_renderer->doc()->buffer(), SIGNAL(textInserted(KTextEditor::Cursor, QString)), this, SLOT(insertText(KTextEditor::Cursor, QString)));
+    connect(&m_renderer->doc()->buffer(), SIGNAL(textRemoved(KTextEditor::Range, QString)), this, SLOT(removeText(KTextEditor::Range)));
 }
 
 void KateLayoutCache::updateViewCache(const KTextEditor::Cursor &startPos, int newViewLineCount, int viewLinesScrolled)
 {
-    //qCDebug(LOG_KTE) << startPos << " nvlc " << newViewLineCount << " vls " << viewLinesScrolled;
+    // qCDebug(LOG_KTE) << startPos << " nvlc " << newViewLineCount << " vls " << viewLinesScrolled;
 
     int oldViewLineCount = m_textLayouts.count();
     if (newViewLineCount == -1) {
@@ -269,8 +260,8 @@ void KateLayoutCache::updateViewCache(const KTextEditor::Cursor &startPos, int n
             m_textLayouts.append(l->viewLine(_viewLine));
         }
 
-        //qCDebug(LOG_KTE) << "Laid out line " << realLine << " (" << l << "), viewLine " << _viewLine << " (" << m_textLayouts[i].kateLineLayout().data() << ")";
-        //m_textLayouts[i].debugOutput();
+        // qCDebug(LOG_KTE) << "Laid out line " << realLine << " (" << l << "), viewLine " << _viewLine << " (" << m_textLayouts[i].kateLineLayout().data() << ")";
+        // m_textLayouts[i].debugOutput();
 
         _viewLine++;
 
@@ -349,22 +340,11 @@ KateLineLayoutPtr KateLayoutCache::line(const KTextEditor::Cursor &realCursor)
 
 KateTextLayout KateLayoutCache::textLayout(const KTextEditor::Cursor &realCursor)
 {
-    /*if (realCursor >= viewCacheStart() && (realCursor < viewCacheEnd() || realCursor == viewCacheEnd() && !m_textLayouts.last().wrap()))
-      foreach (const KateTextLayout& l, m_textLayouts)
-        if (l.line() == realCursor.line() && (l.endCol() < realCursor.column() || !l.wrap()))
-          return l;*/
-
     return line(realCursor.line())->viewLine(viewLine(realCursor));
 }
 
 KateTextLayout KateLayoutCache::textLayout(uint realLine, int _viewLine)
 {
-    /*if (m_textLayouts.count() && (realLine >= m_textLayouts.first().line() && _viewLine >= m_textLayouts.first().viewLine()) &&
-        (realLine <= m_textLayouts.last().line() && _viewLine <= m_textLayouts.first().viewLine()))
-      foreach (const KateTextLayout& l, m_textLayouts)
-        if (l.line() == realLine && l.viewLine() == _viewLine)
-          return const_cast<KateTextLayout&>(l);*/
-
     return line(realLine)->viewLine(_viewLine);
 }
 
@@ -508,13 +488,12 @@ int KateLayoutCache::viewLineCount(int realLine)
 void KateLayoutCache::viewCacheDebugOutput() const
 {
     qCDebug(LOG_KTE) << "Printing values for " << m_textLayouts.count() << " lines:";
-    if (!m_textLayouts.isEmpty()) {
-        foreach (const KateTextLayout &t, m_textLayouts)
-            if (t.isValid()) {
-                t.debugOutput();
-            } else {
-                qCDebug(LOG_KTE) << "Line Invalid.";
-            }
+    for (const KateTextLayout &t : m_textLayouts) {
+        if (t.isValid()) {
+            t.debugOutput();
+        } else {
+            qCDebug(LOG_KTE) << "Line Invalid.";
+        }
     }
 }
 
