@@ -1,6 +1,6 @@
 /* This file is part of the KDE project
 
-   Copyright (C) 2011 Dominik Haumann <dhaumann kde org>
+   Copyright (C) 2011-2018 Dominik Haumann <dhaumann@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -53,8 +53,8 @@ class VariableEditor : public QWidget
     Q_OBJECT
 
 public:
-    VariableEditor(VariableItem *item, QWidget *parent = nullptr);
-    ~VariableEditor() Q_DECL_OVERRIDE;
+    explicit VariableEditor(VariableItem *item, QWidget *parent = nullptr);
+    ~VariableEditor() override;
 
     VariableItem *item() const;
 
@@ -66,9 +66,9 @@ protected Q_SLOTS:
     void activateItem();
 
 protected:
-    void paintEvent(QPaintEvent *event) Q_DECL_OVERRIDE;
-    void enterEvent(QEvent *event) Q_DECL_OVERRIDE;
-    void leaveEvent(QEvent *event) Q_DECL_OVERRIDE;
+    void paintEvent(QPaintEvent *event) override;
+    void enterEvent(QEvent *event) override;
+    void leaveEvent(QEvent *event) override;
 
 private:
     VariableItem *m_item;
@@ -184,4 +184,3 @@ private:
 };
 
 #endif
-
