@@ -20,8 +20,8 @@
  *  Boston, MA 02110-1301, USA.
  */
 
-#ifndef KATEVI_COMMANDS_H
-#define KATEVI_COMMANDS_H
+#ifndef KATEVI_CMDS_H
+#define KATEVI_CMDS_H
 
 #include <KTextEditor/Command>
 #include "kateregexpsearch.h"
@@ -31,29 +31,30 @@
 
 #include <QStringList>
 
-namespace KTextEditor { class DocumentPrivate; }
+namespace KTextEditor
+{
+class DocumentPrivate;
+}
 class KCompletion;
 
 namespace KateVi
 {
-
 /**
  * This KTextEditor::Command provides vi 'ex' commands
  */
 class Commands : public KTextEditor::Command, public KateViCommandInterface
 {
     Commands()
-        : KTextEditor::Command (QStringList() << mappingCommands() << QStringLiteral("d") << QStringLiteral("delete") << QStringLiteral("j") << QStringLiteral("c") << QStringLiteral("change") << QStringLiteral("<") << QStringLiteral(">") << QStringLiteral("y") << QStringLiteral("yank") <<
-          QStringLiteral("ma") << QStringLiteral("mark") << QStringLiteral("k"))
+        : KTextEditor::Command(QStringList() << mappingCommands() << QStringLiteral("d") << QStringLiteral("delete") << QStringLiteral("j") << QStringLiteral("c") << QStringLiteral("change") << QStringLiteral("<") << QStringLiteral(">")
+                                             << QStringLiteral("y") << QStringLiteral("yank") << QStringLiteral("ma") << QStringLiteral("mark") << QStringLiteral("k"))
     {
-        
     }
     static Commands *m_instance;
 
 public:
-    ~Commands()
+    ~Commands() override
     {
-        m_instance = 0;
+        m_instance = nullptr;
     }
 
     /**
@@ -61,17 +62,15 @@ public:
      * @param view view to use for execution
      * @param cmd cmd string
      * @param msg message returned from running the command
-     * @param rangeStart first line in range
-     * @param rangeEnd last line in range
+     * @param range range to execute command on
      * @return success
      */
-    bool exec(class KTextEditor::View *view, const QString &cmd, QString &msg,
-              const KTextEditor::Range &range = KTextEditor::Range(-1, -0, -1, 0)) Q_DECL_OVERRIDE;
+    bool exec(class KTextEditor::View *view, const QString &cmd, QString &msg, const KTextEditor::Range &range = KTextEditor::Range(-1, -0, -1, 0)) override;
 
-    bool supportsRange(const QString &range) Q_DECL_OVERRIDE;
+    bool supportsRange(const QString &range) override;
 
     /** This command does not have help. @see KTextEditor::Command::help */
-    bool help(class KTextEditor::View *, const QString &, QString &) Q_DECL_OVERRIDE
+    bool help(class KTextEditor::View *, const QString &, QString &) override
     {
         return false;
     }
@@ -79,15 +78,16 @@ public:
     /**
      * Reimplement from KTextEditor::Command
      */
-    KCompletion *completionObject(KTextEditor::View *, const QString &) Q_DECL_OVERRIDE;
+    KCompletion *completionObject(KTextEditor::View *, const QString &) override;
 
     static Commands *self()
     {
-        if (m_instance == 0) {
+        if (m_instance == nullptr) {
             m_instance = new Commands();
         }
         return m_instance;
     }
+
 private:
     const QStringList &mappingCommands();
     Mappings::MappingMode modeForMapCommand(const QString &mapCommand);
@@ -100,27 +100,29 @@ private:
  **/
 class SedReplace : public KateCommands::SedReplace, public KateViCommandInterface
 {
-    SedReplace() { }
+    SedReplace()
+    {
+    }
     static SedReplace *m_instance;
 
 public:
-    ~SedReplace()
+    ~SedReplace() override
     {
-        m_instance = 0;
+        m_instance = nullptr;
     }
 
     static SedReplace *self()
     {
-        if (m_instance == 0) {
+        if (m_instance == nullptr) {
             m_instance = new SedReplace();
         }
         return m_instance;
     }
 
 protected:
-    bool interactiveSedReplace(KTextEditor::ViewPrivate *kateView, QSharedPointer<InteractiveSedReplacer> interactiveSedReplace) Q_DECL_OVERRIDE;
+    bool interactiveSedReplace(KTextEditor::ViewPrivate *kateView, QSharedPointer<InteractiveSedReplacer> interactiveSedReplace) override;
 };
 
 }
 
-#endif /* KATEVI_COMMANDS_H */
+#endif /* KATEVI_CMDS_H */
