@@ -21,25 +21,14 @@
 
 namespace KateVi
 {
-    /**
-     * The four vi modes supported by Kate's vi input mode
-     */
-    enum ViMode {
-        NormalMode,
-        InsertMode,
-        VisualMode,
-        VisualLineMode,
-        VisualBlockMode,
-        ReplaceMode
-    };
+/**
+ * The four vi modes supported by Kate's vi input mode
+ */
+enum ViMode { NormalMode, InsertMode, VisualMode, VisualLineMode, VisualBlockMode, ReplaceMode };
 
-    enum OperationMode {
-        CharWise = 0,
-        LineWise,
-        Block
-    };
+enum OperationMode { CharWise = 0, LineWise, Block };
 
-    const unsigned int EOL = 99999;
+const unsigned int EOL = 99999;
 }
 
 #endif // KATEVI_DEFINITIONS_H
